# 
# Copyright (C) 1996-2001 LAAS/CNRS 
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 
#    - Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials provided
#      with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
# 
# $LAAS$
#----------------------------------------------------------------------
package provide Gdhe::models 1.0

proc xr4000Facette {} {
    # La partie centrale
    color 50 50 50
    polygon 4 -0.042 0.1 0.042 0.1 0.042 0.65 -0.042 0.65
    # le capteur du bas
    pushMatrix
    translate 0 0.1 0
    rotate -5 1 0 0
    color 20 20 20
    box 0 -0.05 0 0.084 0.1 0.005
    color 200 200 80
    cylinder 0 -0.05 0.005 z 0.05 0.002
    popMatrix
    # le capteur du haut
    pushMatrix
    translate 0 0.65 0
    rotate 5 1 0 0 
    color 20 20 20
    box 0 0.05 0 0.084 0.1 0.005
    color 200 200 80
    cylinder 0 0.05 0.005 z 0.05 0.002
    popMatrix
}

proc degToRad {x} {
    return [expr $x*3.1415926535/180.0]
}

proc xr4000 {} {
    object Xr4000 {
	# color 255 255 0 
	# repere 1
	concave False
	cullFace True
	for { set i 0 } { $i < 24 } { incr i } {
	    pushMatrix
	    rotate [expr (360 / 24)*$i ] 0 0 1
	    rotate 90 1 0 0 
	    translate 0 0.1 0.31
	    xr4000Facette
	    popMatrix
	}
	# Calcul des polygones superieurs et inferieurs
	set upper {} 
	set lower {}
	for { set i 0 } { $i < 24 } { incr i } {
	    set theta [degToRad [expr (360./24.)*$i + 360.0/48.0 ]]
	    set x [ expr 0.32*cos($theta) ]
	    set y [ expr 0.32*sin($theta) ]
	    set upper [ concat $upper $x $y ]
	    set lower [ concat $x $y $lower ]
	}
	color 50 50 50
	pushMatrix
	translate 0 0 0.11
	eval [ concat polygon 24 $lower]
	translate 0 0 0.73
	eval [ concat polygon 24 $upper]
	popMatrix
	# Les arrets d'urgence
	color 200 0 0
	cylinder 0.22 0 0.85 z 0.04 0.03
	cylinder -0.22 0 0.85 z 0.04 0.03
	# Ethernet radio
	color 180 180 190
	box 0 0.2 0.85 0.12 0.07 0.02
	color 100 100 100
	cylinder 0.04 0.236 0.86 z 0.006 0.003 0.06
	cylinder 0.04 0.164 0.86 z 0.006 0.003 0.06
	
	# Roues
	color 100 100 30
	cylinder 0.23 -0.01 0.05 y 0.1 0.02
	cylinder -0.23 -0.01 0.05 y 0.1 0.02
	cylinder -0.01 0.23 0.05 x 0.1 0.02
	cylinder -0.01 -0.23 0.05 x 0.1 0.02
    }
    pushMatrix
    translate 0.15 0 0.85
    xr4000Platine 0 0 
    popMatrix
}

#----------------------------------------------------------------------
### 
### platine
###
proc xr4000Platine {azi site} {
    pushMatrix
    object platineInf {
        color 30 30 30
        box -0.02 0.0 0 0.08 0.05 0.05
        color 180 180 180
        cylinder -0.075 0 0.025 x 0.012 0.02
    }
    rotate $azi 0 0 1
    object platineMid {
        color 30 30 30
        box -0.02 0 0.051 0.08 0.05 0.05
        color 180 180 180
        cylinder -0.075 0 0.075 x 0.012 0.02
        translate 0 0 0.075
    }
    rotate $site 0 -1 0
    object platineSup {
        color 30 30 30
        box 0 -0.028 -0.01 0.02 0.005 0.05
        box 0  0.028 -0.01 0.02 0.005 0.05
        color 100 100 100
        box 0 0 0.04 0.02 0.2 0.005
        color 20 20 20
        box -0.013 0.07 0.045 0.053 0.045 0.035
        color 70 70 70
        cylinder 0.01 0.07 0.065 x 0.028 0.01
        cylinder 0.02 0.07 0.065 x 0.028 0.05 0.02
        cylinder 0.04 0.07 0.065 x 0.05 0.008
        color 20 20 20
        box -0.013 -0.07 0.045 0.053 0.045 0.035
        color 70 70 70
        cylinder 0.01 -0.07 0.065 x 0.028 0.01
        cylinder 0.02 -0.07 0.065 x 0.028 0.05 0.02
        cylinder 0.04 -0.07 0.065 x 0.05 0.008
    }
    popMatrix
}
